package com.wechi.adweb.bridge.google.analytics.dto.report.data;

import static com.wechi.adweb.bridge.google.analytics.dto.report.ReportConstant.*;

import com.google.analytics.data.v1beta.Row;

import lombok.Builder;
import lombok.Data;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * @author wfansh
 */
@Data
@Builder
public class PageViewsData implements GAReportDataDTO {

    /**
     * Formatted as {@link DateTimeFormatter#ISO_LOCAL_DATE}, originated from {@link
     * DateTimeFormatter#BASIC_ISO_DATE}
     */
    private String date;

    private int pageViews;

    public static List<PageViewsData> toReport(
            List<Row> reportRows, List<String> metrics, List<String> dimensions) {
        int indexDate = dimensions.indexOf(DIMENSION_DATE);
        int indexPageViews = metrics.indexOf(METRIC_SCREEN_PAGE_VIEWS);

        return reportRows.stream()
                .map(
                        row ->
                                PageViewsData.builder()
                                        .date(
                                                LocalDate.parse(
                                                                row.getDimensionValues(indexDate)
                                                                        .getValue(),
                                                                DateTimeFormatter.BASIC_ISO_DATE)
                                                        .format(DateTimeFormatter.ISO_LOCAL_DATE))
                                        .pageViews(
                                                Integer.parseInt(
                                                        row.getMetricValues(indexPageViews)
                                                                .getValue()))
                                        .build())
                .toList();
    }
}
